==> sedaro-1.1.1.tar.gz: sedaro-1.1.1/src/sedaro_base_client/apis/tags/__init__.py <==
# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from sedaro_base_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    BRANCHES = "Branches"
    DATA = "Data"
    ACTUATOR_LOAD = "Actuator Load"
    AGENT = "Agent"
    ANGULAR_VELOCITY_SENSOR = "Angular Velocity Sensor"
    AVERAGING_ALGORITHM = "Averaging Algorithm"
    BATTERY = "Battery"
    BATTERY_CELL = "Battery Cell"
    BATTERY_PACK = "Battery Pack"
    BODY_FRAME_VECTOR = "Body Frame Vector"
    BUS_REGULATOR = "Bus Regulator"
    CELESTIAL_TARGET = "Celestial Target"
    CELESTIAL_VECTOR = "Celestial Vector"
    CIRCULAR_FIELD_OF_VIEW = "Circular Field Of View"
    CLOCK_CONFIG = "Clock Config"
    COMPONENT = "Component"
    CONDITION = "Condition"
    CONSTANT_LOAD = "Constant Load"
    COOLER = "Cooler"
    DIRECTION_SENSOR = "Direction Sensor"
    EKF_ALGORITHM = "EKF Algorithm"
    FOV_CONSTRAINT = "FOV Constraint"
    GPS_ALGORITHM = "GPS Algorithm"
    GROUND_TARGET = "Ground Target"
    GROUP_CONDITION = "Group Condition"
    HEATER = "Heater"
    JOBS = "Jobs"
    LOAD_STATE = "Load State"
    LOCAL_VECTOR = "Local Vector"
    LOCK_POINTING_MODE = "Lock Pointing Mode"
    MEKF_ALGORITHM = "MEKF Algorithm"
    MAGNETORQUER = "Magnetorquer"
    MAX_ALIGN_POINTING_MODE = "Max Align Pointing Mode"
    OPERATIONAL_MODE = "Operational Mode"
    OPTICAL_ATTITUDE_SENSOR = "Optical Attitude Sensor"
    ORBIT = "Orbit"
    PASSIVE_POINTING_MODE = "Passive Pointing Mode"
    POSITION_SENSOR = "Position Sensor"
    REACTION_WHEEL = "Reaction Wheel"
    RECTANGULAR_FIELD_OF_VIEW = "Rectangular Field Of View"
    SATELLITE = "Satellite"
    SLIDING_MODE_ALGORITHM = "Sliding Mode Algorithm"
    SOLAR_ARRAY = "Solar Array"
    SOLAR_CELL = "Solar Cell"
    SOLAR_PANEL = "Solar Panel"
    SPACE_TARGET = "Space Target"
    SUBSYSTEM = "Subsystem"
    SURFACE = "Surface"
    SURFACE_MATERIAL = "Surface Material"
    TARGET_GROUP = "Target Group"
    TARGET_GROUP_VECTOR = "Target Group Vector"
    TARGET_VECTOR = "Target Vector"
    TEMP_CONTROL_LOAD = "Temp Control Load"
    TEMP_CONTROLLER_STATE = "Temp Controller State"
    THERMAL_INTERFACE = "Thermal Interface"
    THERMAL_INTERFACE_MATERIAL = "Thermal Interface Material"
    TOPOLOGY = "Topology"
    TRIAD_ALGORITHM = "Triad Algorithm"
    VECTOR_SENSOR = "Vector Sensor"

==> sedaro-3.3.4.tar.gz: sedaro-3.3.4/src/sedaro_base_client/apis/tags/__init__.py <==
# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from sedaro_base_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    BRANCHES = "Branches"
    DATA = "Data"
    AGENT = "Agent"
    ANGULAR_VELOCITY_SENSOR = "Angular Velocity Sensor"
    AVERAGING_ALGORITHM = "Averaging Algorithm"
    BATTERY = "Battery"
    BATTERY_CELL = "Battery Cell"
    BATTERY_PACK = "Battery Pack"
    BODY_FRAME_VECTOR = "Body Frame Vector"
    BUS_REGULATOR = "Bus Regulator"
    CELESTIAL_TARGET = "Celestial Target"
    CELESTIAL_VECTOR = "Celestial Vector"
    CIRCULAR_FIELD_OF_VIEW = "Circular Field Of View"
    CLOCK_CONFIG = "Clock Config"
    COMPONENT = "Component"
    CONDITION = "Condition"
    CONSTANT_LOAD = "Constant Load"
    COOLER = "Cooler"
    DIRECTION_SENSOR = "Direction Sensor"
    EKF_ALGORITHM = "EKF Algorithm"
    FOV_CONSTRAINT = "FOV Constraint"
    GPS_ALGORITHM = "GPS Algorithm"
    GROUND_TARGET = "Ground Target"
    GROUP_CONDITION = "Group Condition"
    HEATER = "Heater"
    JOBS = "Jobs"
    LOAD_STATE = "Load State"
    LOCAL_VECTOR = "Local Vector"
    LOCK_POINTING_MODE = "Lock Pointing Mode"
    MEKF_ALGORITHM = "MEKF Algorithm"
    MAGNETORQUER = "Magnetorquer"
    MAX_ALIGN_POINTING_MODE = "Max Align Pointing Mode"
    OPERATIONAL_MODE = "Operational Mode"
    OPTICAL_ATTITUDE_SENSOR = "Optical Attitude Sensor"
    ORBIT = "Orbit"
    PID_ALGORITHM = "PID Algorithm"
    PASSIVE_POINTING_MODE = "Passive Pointing Mode"
    POSITION_SENSOR = "Position Sensor"
    REACTION_WHEEL = "Reaction Wheel"
    RECTANGULAR_FIELD_OF_VIEW = "Rectangular Field Of View"
    SATELLITE = "Satellite"
    SLIDING_MODE_ALGORITHM = "Sliding Mode Algorithm"
    SOLAR_ARRAY = "Solar Array"
    SOLAR_CELL = "Solar Cell"
    SOLAR_PANEL = "Solar Panel"
    SPACE_TARGET = "Space Target"
    SUBSYSTEM = "Subsystem"
    SURFACE = "Surface"
    SURFACE_MATERIAL = "Surface Material"
    TARGET_GROUP = "Target Group"
    TARGET_GROUP_VECTOR = "Target Group Vector"
    TARGET_VECTOR = "Target Vector"
    TEMP_CONTROLLER_STATE = "Temp Controller State"
    THERMAL_INTERFACE = "Thermal Interface"
    THERMAL_INTERFACE_MATERIAL = "Thermal Interface Material"
    TOPOLOGY = "Topology"
    TRIAD_ALGORITHM = "Triad Algorithm"
    VECTOR_SENSOR = "Vector Sensor"
